@@ -79,8 +79,6 @@ class SegmentHook(BaseHook):
         return analytics
 
     def on_error(self, error: str, items: str) -> None:
-        """
-        Handles error callbacks when using Segment with segment_debug_mode set to True
-        """
+        """Handles error callbacks when using Segment with segment_debug_mode set to True"""
         self.log.error('Encountered Segment error: %s with ' 'items: %s', error, items)
         raise AirflowException('Segment error: {}'.format(error))
